// 布局元素不能用 transform: translateX(-${value}px);

import { DefaultOptons, cssEffectConfig, Options,paramCore } from "../types/index"
import { handleUserControlEnter, handleUserControlLeave, handleCommonControlEnter } from "../utils/common"
import {scrollFrameWatch } from "../services/frameFn"
import cache from '../utils/cache'

// cache.get("humanRectCx") ? cache.get("humanRectCx") : 0.7



class cssEffect {
    public data: DefaultOptons;
    public constructor(options: Options) {
        this.data = Object.assign(this.init(), options)
        this.init()
        cache.set('time', this.data?.time ?? 1)
        cache.set('delay', this.data?.delay ?? 0)
    }

    public config() {
        console.log(this.data)

    }
    private init(): DefaultOptons {
        return <DefaultOptons>{
            sdkVersion: cssEffectConfig.version,
        }
    }
    /**
     * 一：省事模式：显示完毕就不管了
     * 第一个分类：开始进入的时候
     * @param element 传入的元素，暂时只是单个元素，需要指定一个唯一的标识符号 css_index
     * @param distance_viewable_num 可视区距离顶部距离的高度
     * @param distance_css_num css移动的距离
     * @param key 需要指定唯一的key
     */
    public commonEnterUp(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key}  = data
        
        handleCommonControlEnter(element, distance_viewable_num, distance_css_num, key, "towardUp")
    }
    public commonEnterLeft(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key}  = data
        handleCommonControlEnter(element, distance_viewable_num, distance_css_num, key, "towardLeft")

    }
    public commonEnterRight(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key}  = data
        handleCommonControlEnter(element, distance_viewable_num, distance_css_num, key, "towardRight")
    }

    /**
     * 二：用户自己控制
     * 2.1：开始进入的时候
     * @param element 传入的元素，暂时只是单个元素，需要指定一个唯一的标识符号 css_index
     * @param distance_viewable_num 可视区距离顶部距离的高度
     * @param distance_css_num css移动的距离
     * @param key 需要指定唯一的key
     */
    public userEnterUp(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key,distance_unshow_num}  = data
        handleUserControlEnter(element, distance_viewable_num, distance_css_num, key, distance_unshow_num, "towardUp")
    }
    public userEnterBottom(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key,distance_unshow_num}  = data
        handleUserControlEnter(element, distance_viewable_num, distance_css_num, key, distance_unshow_num, "towardDown")
    }
    public userEnterRight(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key,distance_unshow_num}  = data
        handleUserControlEnter(element, distance_viewable_num, distance_css_num, key, distance_unshow_num, "towardRight")
    }

    // 可视区向左边走
    public userEnterLeft(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key,distance_unshow_num}  = data
        handleUserControlEnter(element, distance_viewable_num, distance_css_num, key, distance_unshow_num, "towardLeft")
    }



    /**
     * 二：用户自己控制
     * 2.2：离开的时候
     * @param element 传入的元素，暂时只是单个元素，需要指定一个唯一的标识符号 css_index
     * @param distance_viewable_num 可视区距离顶部距离的高度
     * @param distance_css_num css移动的距离
     * @param key 需要指定唯一的key
     */
    public userLeaveLeft(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key,distance_unshow_num}  = data
        handleUserControlLeave(element, distance_viewable_num, distance_css_num, key, "leaveLeft")
    }
    public userLeaveRight(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key,distance_unshow_num}  = data
        handleUserControlLeave(element, distance_viewable_num, distance_css_num, key, "leaveRight")
    }
    public userLeaveDown(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num, key,distance_unshow_num}  = data
        handleUserControlLeave(element, distance_viewable_num, distance_css_num, key, "leaveDown")
    }




    /**
     * 三：通过帧来进行控制
     * 3.1
     * @param element 传入的元素，暂时只是单个元素，需要指定一个唯一的标识符号 css_index
     * @param distance_viewable_num 可视区距离顶部距离的高度
     * @param distance_css_num css移动的距离
     * @param key 需要指定唯一的key
     */
    public frameLeft(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num}  = data
        window.addEventListener('scroll', () => {
            scrollFrameWatch(element,distance_viewable_num,distance_css_num,"towardLeft")

        });
    }
    public frameRight(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num}  = data
        window.addEventListener('scroll', () => {
            scrollFrameWatch(element,distance_viewable_num,distance_css_num,"towardRight")
        });
    }

    public frameTop(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num}  = data
        window.addEventListener('scroll', () => {
            scrollFrameWatch(element,distance_viewable_num,distance_css_num,"towardUp")
        });
    }

    public frameBottom(data:paramCore) {
        let {element, distance_viewable_num, distance_css_num}  = data
        window.addEventListener('scroll', () => {
            scrollFrameWatch(element,distance_viewable_num,distance_css_num,"towardDown")
        });
    }
}

export {
    cssEffect
}
